# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['samplingsimulatorpy']

package_data = \
{'': ['*']}

install_requires = \
['altair>=3.3.0', 'numpy>=1.18.1,<2.0.0', 'pandas>=1.0.1,<2.0.0']

setup_kwargs = {
    'name': 'samplingsimulatorpy',
    'version': '0.1.0',
    'description': 'This is a sampling simulator',
    'long_description': '## samplingsimulatorpy \n\n![build](https://github.com/UBC-MDS/samplingsimulatorpy/workflows/build/badge.svg) [![codecov](https://codecov.io/gh/UBC-MDS/samplingsimulatorpy/branch/master/graph/badge.svg)](https://codecov.io/gh/UBC-MDS/samplingsimulatorpy) ![Release](https://github.com/UBC-MDS/samplingsimulatorpy/workflows/Release/badge.svg)\n\n[![Documentation Status](https://readthedocs.org/projects/samplingsimulatorpy/badge/?version=latest)](https://samplingsimulatorpy.readthedocs.io/en/latest/?badge=latest)\n\n\n`samplingsimulatorpy` is a Python package intended to assist those teaching or learning basic statistical inference.\n\n### Authors\n\n| Name             | GitHub                                          |\n| ---------------- | ----------------------------------------------- |\n| Holly Williams   | [hwilliams10](https://github.com/hwilliams10)   |\n| Lise Braaten     | [lisebraaten](https://github.com/lisebraaten)   |\n| Tao Guo          | [tguo9](https://github.com/tguo9)               |\n| Yue (Alex) Jiang | [YueJiangMDSV](https://github.com/YueJiangMDSV) |\n\n### Overview\n\nThis package allows users to generate virtual populations which can be sampled from in order to compare and contrast sample vs sampling distributions for different sample sizes.  The package also allows users to sample from the generated virtual population (or any other population), plot the distributions, and view summaries for the parameters of interest.\n\n## Installation:\n\n```\npip install -i https://test.pypi.org/simple/ samplingsimulatorpy\n```\n\n\n## Function Descriptions\n\n- `generate_virtual_pop` creates a virtual population.\n    - **Inputs** : distribution function (i.e. `np.random.lognormal`, `np.random.binomial`, etc), the parameters required by the distribution function, and the size of the population.\n    - **Outputs**: the virtual population as a tibble\n- `draw_samples` generates samples of different sizes\n    - **Inputs** : population to sample from, the sample size, and the number of samples\n    - **Outputs**: returns a tibble with the sample number in one column and value in a second column.\n- `plot_sample_hist` creates sample distributions for different sample sizes.\n    - **Inputs** : population to sample from, the samples to plot, and a vector of the sample sizes\n    - **Outputs**: returns a grid of sample distribution plots\n- `plot_sampling_dist` creates sampling distributions for different sample sizes.\n    - **Inputs** : population to sample from, the samples to plot, and a vector of the sample sizes\n    - **Outputs**: returns a grid of sampling distribution plots\n- `stat_summary`: returns a summary of the statistical parameters of interest\n    - **Inputs**: population, samples, parameter(s) of interest\n    - **Outputs**: summary tibble\n\n\n#### How do these fit into the Python ecosystem?\n\nTo the best of our knowledge, there is currently no existing Python package with the specific functionality to create virtual populations and make the specific sample and sampling distributions described above. We do make use of many existing Python packages and expand on them to make very specific functions. These include:\n - `scipy.stats` to get distribution functions\n - `np.random` to generate random samples\n - [Altair](https://altair-viz.github.io/) to create plots\n\n Python `pandas` already includes some summary statistics functions such as `.describe()`, however our package will be more customizable.  Our summary will only include the statistical parameters of interest and will provide a comparison between the sample, sampling, and true population parameters.\n\n### Dependencies\n\n- python = "^3.7"\n- pandas = "^1.0.1"\n- numpy = "^1.18.1"\n- altair = "^4.0.1"\n\n## Usage\n\n#### `generate_virtual_pop`\n\n``` \nfrom samplingsimulatorpy import generate_virtual_pop\ngenerate_virtual_pop(size, distribution_func, *para)\n```\n\n**Arguments:**\n\n  - `size`: The number of samples\n  - `distribution_func`: The distribution that we are generating samples from\n  - `*para`: The arguments required for the distribution function\n\n**Example:**\n\n`pop = generate_virtual_pop(100, np.random.normal, 0, 1)`\n\n#### `draw_samples`\n\n``` \nfrom samplingsimulatorpy import draw_samples\ndraw_samples(pop, reps, n_s)\n```\n\n**Arguments:**\n\n  - `pop` the virtual population as a data frame\n  - `reps` the number of replication for each sample size as an integer\n    value\n  - `n_s` the sample size for each one of the samples as a list\n\n**Example:**\n\n`samples = draw_samples(pop, 3, [5, 10, 15, 20])`\n\n#### `plot_sample_hist`\n\n``` \nfrom samplingsimulatorpy import plot_sample_hist\nplot_sample_hist(pop, samples)\n```\n\n**Arguments:**\n\n  - `pop` the virtual population as a data frame\n  - `samples` the samples as a data frame\n\n**Example:**\n\n`plot_sample_hist(samples)`\n\n#### `plot_sampling_hist`\n\n``` \nfrom samplingsimulatorpy import plot_sampling_hist\nplot_sampling_hist(pop, samples)\n```\n\n**Arguments:**\n\n  - `samples` the samples as a data frame\n\n**Example:**\n\n`plot_sampling_hist(samples)`\n\n#### `stat_summary`\n\n``` \nfrom samplingsimulatorpy import stat_summary\nplot_sampling_hist(pop, samples, parameter)\n```\n\n**Arguments**\n\n  - `population` The virtual population\n  - `samples` The drawed samples\n  - `parameter` The parameter(s) of interest\n\n**Example**\n\n`stat_summary(pop, samples, [\'np.mean\', \'np.std\'])`\n\n### Example Usage Scenario\n\n```python\nfrom samplingsimulatorpy import generate_virtual_pop,\n                                draw_samples,\n                                plot_sample_dist,\n                                plot_sampling_dist,\n                                stat_summary\n# create virtual population\npop = generate_virtual_pop(100, np.random.normal, 0, 1)\n# take samples\nsamples = draw_samples(pop, 3, [10, 20])\n# plot sample histogram\nplot_sample_hist(pop, samples)\n```\n![](img/sample_dist_output.png)\n\n```python\n# plot sampling distribution\nplot_sampling_hist(samples)\n```\n![](img/sampling_dist_output.png)\n\n```python\n# compare mean and standard deviation\nstat_summary(pop, samples, [\'np.mean\', \'np.std\'])\n```\n\n![](img/stat_summary_output.png)\n\n### Documentation\nThe official documentation is hosted on Read the Docs: <https://samplingsimulatorpy.readthedocs.io/en/latest/>\n\n### Credits\nThis package was created with Cookiecutter and the UBC-MDS/cookiecutter-ubc-mds project template, modified from the [pyOpenSci/cookiecutter-pyopensci](https://github.com/pyOpenSci/cookiecutter-pyopensci) project template and the [audreyr/cookiecutter-pypackage](https://github.com/audreyr/cookiecutter-pypackage).\n',
    'author': 'Your Name',
    'author_email': 'you@example.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/UBC-MDS/samplingsimulatorpy',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)
